pub struct ScoreState {
pub max_combo: u32,
pub osu_large_tick_hits: u32,
pub osu_small_tick_hits: u32,
pub slider_end_hits: u32,
pub n_geki: u32,
pub n_katu: u32,
pub n300: u32,
pub n100: u32,
pub n50: u32,
pub misses: u32,
pub legacy_total_score: Option<u32>,
}Expand description
Aggregation for a score’s current state.
Fields
max_combo: u32Maximum combo that the score has had so far. Not the maximum possible combo of the map so far.
Note that for osu!catch only fruits and droplets are considered for combo.
Irrelevant for osu!mania.
osu_large_tick_hits: u32“Large tick” hits for osu!standard.
The meaning depends on the kind of score:
- if set on osu!stable, this field is irrelevant and can be
0 - if set on osu!lazer with slider accuracy, this field is the amount of hit slider ticks and repeats
- if set on osu!lazer without slider accuracy, this field is the amount of hit slider heads, ticks, and repeats
Only relevant for osu!lazer.
osu_small_tick_hits: u32“Small ticks” hits for osu!standard.
These are essentially the slider end hits for lazer scores without slider accuracy.
Only relevant for osu!lazer.
slider_end_hits: u32Amount of successfully hit slider ends.
Only relevant for osu!standard in lazer.
n_geki: u32Amount of current gekis (n320 for osu!mania).
n_katu: u32Amount of current katus (tiny droplet misses for osu!catch / n200 for osu!mania).
n300: u32Amount of current 300s (fruits for osu!catch).
n100: u32Amount of current 100s (droplets for osu!catch).
n50: u32Amount of current 50s (tiny droplets for osu!catch).
misses: u32Amount of current misses (fruits + droplets for osu!catch).
legacy_total_score: Option<u32>Legacy total score.
Only relevant for osu!standard in stable.
Implementations
Sourceimpl ScoreState
impl ScoreState