CatchHitResults

Struct CatchHitResults 

pub struct CatchHitResults {
    pub fruits: u32,
    pub droplets: u32,
    pub tiny_droplets: u32,
    pub tiny_droplet_misses: u32,
    pub misses: u32,
}
osu!catch hitresults.

Fields

fruits: u32

Amount of current fruits (300s).

droplets: u32

Amount of current droplets (100s).

tiny_droplets: u32

Amount of current tiny droplets (50s).

tiny_droplet_misses: u32

Amount of current tiny droplet misses (katus).

misses: u32

Amount of current misses (fruits and droplets).

Implementations

Source

impl CatchHitResults

pub const fn new() -> Self

Create a new empty score state.

pub const fn total_hits(&self) -> u32

Return the total amount of hits by adding everything up.

pub const fn total_successful_hits(&self) -> u32

Return the total amount of successful hits by adding up fruits, droplets, and tiny droplets.

pub fn accuracy(&self) -> f64

Calculate the accuracy between 0.0 and 1.0 for this state.