BeatmapAttribute

Enum BeatmapAttribute 

pub enum BeatmapAttribute {
    None,
    Value(f32),
    Given(f32),
    Fixed(f32),
}
A beatmap attribute.

It contains either:

  • the default value (5.0)
  • a value taken from a Beatmap or mutated default value
  • a user-given value that may be adjusted
  • a user-given fixed value that will stay as-is

Variants



None

No value has been set.

Will be treated as the default value (5.0).



Value(f32)

Variable value taken from a Beatmap or mutated default value that may be overriden and adjusted based on mods and clock rate.



Given(f32)

Given by the user and may not be overriden by custom mod values.

Mods and clock rate may adjust the value, though.

Example

Mods include DifficultyAdjust which sets AR to 9.5 but the user specified AR to be 9.7. In this case, the user’s value is should take precedence.



Fixed(f32)

Represents a final value that should not be adjusted based on mods or clock rate.

Implementations

Source

impl BeatmapAttribute

pub const DEFAULT: f32 = 5.0

The default value for a BeatmapAttribute.

pub const fn overwrite(self, other: Self) -> Self

Overwrites self with other if other is not None.

pub fn try_mutate(&mut self, f: impl Fn(&mut f32))

Mutates the Value and Given variants.

pub const fn try_set(&mut self, value: f32)

Sets the Value variant only.

pub fn map_or_else<U, D, F>(self, default: D, f: F) -> U
where D: FnOnce(f32) -> U, F: FnOnce(f32) -> U,

Applies f onto the Value and Given variants and default onto the Fixed variant.

pub const fn get_raw(self) -> f32