pub struct TaikoPerformanceAttributes {
pub difficulty: TaikoDifficultyAttributes,
pub pp: f64,
pub pp_acc: f64,
pub pp_difficulty: f64,
pub effective_miss_count: f64,
pub estimated_unstable_rate: Option<f64>,
}Expand description
The result of a performance calculation on an osu!taiko map.
Fields
difficulty: TaikoDifficultyAttributesThe difficulty attributes that were used for the performance calculation
pp: f64The final performance points.
pp_acc: f64The accuracy portion of the final pp.
pp_difficulty: f64The strain portion of the final pp.
effective_miss_count: f64Scaled miss count based on total hits.
estimated_unstable_rate: Option<f64>Upper bound on the player’s tap deviation.
Implementations
Sourceimpl TaikoPerformanceAttributes
impl TaikoPerformanceAttributes
Sourcepub const fn is_convert(&self) -> bool
pub const fn is_convert(&self) -> bool
Whether the Beatmap was a convert i.e. an osu!standard map.
Sourcepub fn performance<'a>(self) -> TaikoPerformance<'a>
pub fn performance<'a>(self) -> TaikoPerformance<'a>
Returns a builder for performance calculation.