pub struct CatchHitResults {
pub fruits: u32,
pub droplets: u32,
pub tiny_droplets: u32,
pub tiny_droplet_misses: u32,
pub misses: u32,
}Expand description
osu!catch hitresults.
Fields
fruits: u32Amount of current fruits (300s).
droplets: u32Amount of current droplets (100s).
tiny_droplets: u32Amount of current tiny droplets (50s).
tiny_droplet_misses: u32Amount of current tiny droplet misses (katus).
misses: u32Amount of current misses (fruits and droplets).
Implementations
Sourceimpl CatchHitResults
impl CatchHitResults
Sourcepub const fn total_hits(&self) -> u32
pub const fn total_hits(&self) -> u32
Return the total amount of hits by adding everything up.
Sourcepub const fn total_successful_hits(&self) -> u32
pub const fn total_successful_hits(&self) -> u32
Return the total amount of successful hits by adding up fruits, droplets, and tiny droplets.