pub enum BeatmapAttribute {
None,
Value(f32),
Given(f32),
Fixed(f32),
}Expand description
A beatmap attribute.
It contains either:
- the default value (5.0)
- a value taken from a
Beatmapor mutated default value - a user-given value that may be adjusted
- a user-given fixed value that will stay as-is
Variants
None
No value has been set.
Will be treated as the default value (5.0).
Value(f32)
Variable value taken from a Beatmap or mutated default value that
may be overriden and adjusted based on mods and clock rate.
Given(f32)
Given by the user and may not be overriden by custom mod values.
Mods and clock rate may adjust the value, though.
Example
Mods include DifficultyAdjust which sets AR to 9.5 but the user
specified AR to be 9.7. In this case, the user’s value is should take
precedence.
Fixed(f32)
Represents a final value that should not be adjusted based on mods or clock rate.
Implementations
Sourceimpl BeatmapAttribute
impl BeatmapAttribute
Sourcepub const fn overwrite(self, other: Self) -> Self
pub const fn overwrite(self, other: Self) -> Self
Overwrites self with other if other is not None.
Sourcepub fn try_mutate(&mut self, f: impl Fn(&mut f32))
pub fn try_mutate(&mut self, f: impl Fn(&mut f32))
Mutates the Value and Given variants.
Sourcepub fn map_or_else<U, D, F>(self, default: D, f: F) -> U
pub fn map_or_else<U, D, F>(self, default: D, f: F) -> U
Applies f onto the Value and Given variants and default onto the
Fixed variant.
pub const fn get_raw(self) -> f32