BeatmapAttributesBuilder

Struct BeatmapAttributesBuilder 

pub struct BeatmapAttributesBuilder { /* private fields */ }
A builder for BeatmapAttributes.

Implementations

Source

impl BeatmapAttributesBuilder

pub const fn new() -> Self

Create a new BeatmapAttributesBuilder.

The mode will be GameMode::Osu and attributes are set to 5.0.

pub const fn map(&mut self, map: &Beatmap) -> &mut Self

Use the given Beatmap’s attributes, mode, and convert status.

pub const fn ar(&mut self, ar: f32, fixed: bool) -> &mut Self

Specify the approach rate.

fixed determines if the given value should be used before or after accounting for mods, e.g. on true the value will be used as-is and on false it will be modified based on the mods.

pub const fn od(&mut self, od: f32, fixed: bool) -> &mut Self

Specify the overall difficulty.

fixed determines if the given value should be used before or after accounting for mods, e.g. on true the value will be used as-is and on false it will be modified based on the mods.

pub const fn cs(&mut self, cs: f32, fixed: bool) -> &mut Self

Specify the circle size.

fixed determines if the given value should be used before or after accounting for mods, e.g. on true the value will be used as-is and on false it will be modified based on the mods.

pub const fn hp(&mut self, hp: f32, fixed: bool) -> &mut Self

Specify the drain rate.

fixed determines if the given value should be used before or after accounting for mods, e.g. on true the value will be used as-is and on false it will be modified based on the mods.

pub fn mods(&mut self, mods: impl Into<GameMods>) -> &mut Self

pub const fn clock_rate(&mut self, clock_rate: f64) -> &mut Self

Specify a custom clock rate.

pub const fn mode(&mut self, mode: GameMode, is_convert: bool) -> &mut Self

Specify a GameMode and whether it’s a converted map.

pub fn difficulty(&mut self, difficulty: &Difficulty) -> &mut Self

Specify all settings through Difficulty.

pub fn build(&self) -> BeatmapAttributes

Calculate the BeatmapAttributes.